@@ -47,7 +47,6 @@ from .graph_rewriter.generic.fold_batch_norm import FoldBatchNormNodesOptimizer
 from .graph_rewriter.generic.fuse_pad_with_conv import FusePadWithConv2DOptimizer
 
 from .graph_rewriter.int8.freeze_value import FreezeValueTransformer
-from .graph_rewriter.int8.freeze_value_without_calib import FreezeValueWithoutCalibTransformer
 from .graph_rewriter.int8.freeze_fake_quant import FreezeFakeQuantOpOptimizer
 from .graph_rewriter.int8.fuse_conv_requantize import FuseConvRequantizeTransformer
 from .graph_rewriter.int8.fuse_matmul_requantize import FuseMatMulRequantizeTransformer
@@ -62,7 +61,7 @@ from neural_compressor.adaptor.tf_utils.graph_rewriter.generic.insert_print_node
 from neural_compressor.adaptor.tf_utils.graph_rewriter.graph_util import GraphRewriterHelper as Helper
 
 
-TF_SUPPORTED_MAX_VERSION = '2.6.0'
+TF_SUPPORTED_MAX_VERSION = '2.7.0'
 TF_SUPPORTED_MIN_VERSION = '1.14.0'
 
 logger = logging.getLogger()
@@ -177,8 +176,9 @@ class GraphConverter:
             if IsMklEnabled() and (TF_SUPPORTED_MIN_VERSION <= tf.version.VERSION):
                 is_supported_version = True
 
-            if tf.version.VERSION == '2.6.0' and os.getenv('TF_ENABLE_ONEDNN_OPTS') == '1':
+            if tf.version.VERSION >= '2.6.0' and os.getenv('TF_ENABLE_ONEDNN_OPTS') == '1':
                 is_supported_version = True
+
         except Exception as e:
             raise ValueError(e)
         finally:
@@ -194,9 +194,9 @@ class GraphConverter:
                 logger.fatal("Please set environment variable TF_ENABLE_MKL_NATIVE_FORMAT=0 "
                              "when Tensorflow 2.5.0 installed.")
 
-            if tf.version.VERSION == '2.6.0' and os.getenv('TF_ENABLE_ONEDNN_OPTS') != '1':
+            if tf.version.VERSION >= '2.6.0' and os.getenv('TF_ENABLE_ONEDNN_OPTS') != '1':
                 logger.fatal("Please set environment variable TF_ENABLE_ONEDNN_OPTS=1 "
-                             "when Tensorflow 2.6.0 installed.")
+                             "when Tensorflow 2.6.x installed.")
 
             if not is_supported_version:
                 raise ValueError(
@@ -485,20 +485,6 @@ class GraphConverter:
 
         return final_result
 
-    def _analysis_rnn_model(self):
-        g = GraphAnalyzer()
-        g.graph = self._tmp_graph_def
-        graph_info = g.parse_graph()
-        rnn_pattern = [['TensorArrayV3'], ['Enter'], ['TensorArrayReadV3'], \
-            ['MatMul'], ['BiasAdd']]
-        target_nodes = g.query_fusion_pattern_nodes(rnn_pattern)
-        res = {}
-        for i in target_nodes:
-            if i[-3] not in self.bf16_ops and i[-3] not in self.fp32_ops:
-                res[(i[-3], i[-2])] = graph_info[i[1]].node.attr['frame_name'].s.decode()
-
-        return res
-
     def _search_y_pattern_for_itex(self):
         """Search the Y pattern for itex and return the op name.
         """
@@ -526,7 +512,9 @@ class GraphConverter:
         """
         try:
             self._quantize_graph()
-            self._rnn_details = self._analysis_rnn_model()
+            self._rnn_details = Helper.analysis_rnn_model(self._tmp_graph_def,
+                                                            bf16_ops=self.bf16_ops,
+                                                            fp32_ops=self.fp32_ops)
             self.quantized_node_info.extend(self._rnn_details.keys())
             self.quantized_node_info = [tuple(i) for i in self.quantized_node_info]
 
