@@ -282,7 +282,8 @@ transform_schema = Schema({
     Optional('ToPILImage'): Or({}, None),
     Optional('Normalize'): {
         Optional('mean'): And(list, lambda s: all(isinstance(i, float) for i in s)),
-        Optional('std'): And(list, lambda s: all(isinstance(i, float) for i in s))
+        Optional('std'): And(list, lambda s: all(isinstance(i, float) for i in s)),
+        Optional('rescale'): list
     },
     Optional('Resize'): {
         'size': Or(And(list, lambda s: all(isinstance(i, int) for i in s)),
@@ -393,7 +394,7 @@ dataset_schema = Schema({
     },
     Optional('dummy_v2'): {
         'input_shape': And(Or(str, list), Use(list_to_tuple)),
-        Optional('label_shape'): And(Or(str, list), Use(list_to_tuple)),
+        Optional('label_shape', default=[1]): And(Or(str, list), Use(list_to_tuple)),
         Optional('low'): Or(
             float,
             And(int, Use(input_int_to_float)),
@@ -475,7 +476,7 @@ dataset_schema = Schema({
 
 dataloader_schema = Schema({
     Optional('last_batch', default='rollover'): And(str, lambda s: s in ['rollover', 'discard']),
-    Optional('batch_size', default=1): And(int, lambda s: s > 0),
+    Optional('batch_size', default=None): And(int, lambda s: s > 0),
     'dataset': dataset_schema,
     Optional('filter'): filter_schema,
     Optional('transform'): transform_schema,
@@ -516,6 +517,7 @@ train_schema = Schema({
     'optimizer': optimizer_schema,
     'criterion': criterion_schema,
     Optional('dataloader'): dataloader_schema,
+    Optional('epoch', default=1): int,
     Optional('start_epoch', default=0): int,
     Optional('end_epoch'): int,
     Optional('iteration'): int,
@@ -540,6 +542,13 @@ approach_schema = Schema({
 default_workspace = './nc_workspace/{}/'.format(
                                            datetime.datetime.now().strftime('%Y-%m-%d_%H-%M-%S'))
 
+COCOmAP_input_order_schema = Schema({
+    Optional('num_detections'): int,
+    'boxes': int,
+    'scores': int,
+    'classes': int
+})
+
 schema = Schema({
     'model': {
         'name': str,
@@ -691,6 +700,14 @@ schema = Schema({
                     Optional('anno_path'): str,
                     Optional('map_key', default='DetectionBoxes_Precision/mAP'): str
                 },
+                Optional('COCOmAPv2'): {
+                    Optional('anno_path'): str,
+                    Optional('map_key', default='DetectionBoxes_Precision/mAP'): str,
+                    Optional('output_index_mapping', default={'num_detections': -1, 
+                                                      'boxes': 0, 
+                                                      'scores': 1, 
+                                                      'classes': 2}): COCOmAP_input_order_schema
+                },
                 Optional('VOCmAP'): {
                     Optional('anno_path'): str
                 },
