@@ -21,6 +21,9 @@ from neural_compressor.experimental.common import Optimizers, Criterions
 from collections import OrderedDict
 import copy
 
+DEFAULT_BATCH_SIZE = 64
+
+
 def get_func_from_config(func_dict, cfg, compose=True):
     func_list = []
     for func_name, func_value in OrderedDict(cfg).items():
@@ -79,7 +82,7 @@ def create_dataset(framework, data_source, cfg_preprocess, cfg_filter):
 
 def create_dataloader(framework, dataloader_cfg):
     batch_size = int(dataloader_cfg['batch_size']) \
-        if dataloader_cfg.get('batch_size') is not None else 1
+        if dataloader_cfg.get('batch_size') is not None else DEFAULT_BATCH_SIZE
     last_batch = dataloader_cfg['last_batch'] \
         if dataloader_cfg.get('last_batch') is not None else 'rollover'
     shuffle = dataloader_cfg['shuffle'] \
@@ -137,7 +140,7 @@ def create_eval_func(framework, dataloader, adaptor,
     return eval_func
 
 
-def create_train_func(framework, dataloader, adaptor, train_cfg, hooks=None):
+def create_train_func(framework, dataloader, adaptor, train_cfg, hooks=None, callbacks=None):
     """The interface to create train function from config.
 
     Args:
@@ -164,8 +167,11 @@ def create_train_func(framework, dataloader, adaptor, train_cfg, hooks=None):
         optimizer = Optimizers(framework)[key](value)
         optimizer = optimizer()
     else:
-        optimizer = (lambda mp, p: train_cfg.optimizer, {'p':0})
-    
+        if framework == "pytorch":
+            optimizer = (lambda mp, p: train_cfg.optimizer, {'p':0})
+        elif framework == 'tensorflow':
+            optimizer = (lambda p: train_cfg.optimizer, {'p':0})
+
     if isinstance(train_cfg.criterion, dict):
         assert train_cfg.criterion and len(train_cfg.criterion) == 1, \
             "criterion should only set once"
@@ -177,6 +183,7 @@ def create_train_func(framework, dataloader, adaptor, train_cfg, hooks=None):
 
     default_dict = {k: train_cfg[k] for k in train_cfg.keys() - {'optimizer', 'criterion',
                                                                  'dataloader'}}
+    default_dict['callbacks'] = callbacks
 
     def train_func(model):
         return adaptor.train(model, dataloader, optimizer_tuple=optimizer,
@@ -184,4 +191,4 @@ def create_train_func(framework, dataloader, adaptor, train_cfg, hooks=None):
     # TODO: to find a better way
     train_func.builtin = True
 
-    return train_func
\ No newline at end of file
+    return train_func
